# -*- coding: utf-8 -*-
# Copyright (c) 2017 Richard Hull and contributors
# See LICENSE.rst for details.

_DIGITS = {
    ' ': 0x00,
    '\'': 0x01,
    ',': 0x80,
    '-': 0x02,
    '.': 0x80,
    '0': 0x7d,
    '1': 0x60,
    '2': 0x3e,
    '3': 0x7a,
    '4': 0x63,
    '5': 0x5b,
    '6': 0x5f,
    '7': 0x70,
    '8': 0x7f,
    '9': 0x7b,
    'A': 0x77,
    'B': 0x7f,
    'C': 0x1d,
    'D': 0x7d,
    'E': 0x1f,
    'F': 0x17,
    'G': 0x5d,
    'H': 0x67,
    'I': 0x60,
    'J': 0x68,
    # 'K': cant represent
    'L': 0x0d,
    # 'M': cant represent
    'N': 0x75,
    'O': 0x7d,
    'P': 0x37,
    'Q': 0x73,
    'R': 0x15,
    'S': 0x5b,
    'T': 0x0f,
    'U': 0x6d,
    'V': 0x6d,
    # 'W': cant represent
    # 'X': cant represent
    'Y': 0x6b,
    'Z': 0x3e,
    '_': 0x08,
    'a': 0x7e,
    'b': 0x4f,
    'c': 0x0e,
    'd': 0x6e,
    'e': 0x3f,
    'f': 0x17,
    'g': 0x7b,
    'h': 0x47,
    'i': 0x40,
    'j': 0x48,
    # 'k': cant represent
    'l': 0x05,
    # 'm': cant represent
    'n': 0x46,
    'o': 0x4e,
    'p': 0x37,
    'q': 0x73,
    'r': 0x06,
    's': 0x5b,
    't': 0x0f,
    'u': 0x4c,
    'v': 0x4c,
    # 'w': cant represent
    # 'x': cant represent
    'y': 0x6b,
    'z': 0x3e
}


def dot_muncher(text, notfound="_"):
    undefined = _DIGITS[notfound]
    iterator = iter(text)
    try:
        while True:
            curr = _DIGITS.get(next(iterator), undefined)

            if curr == 0x80:
                curr = _DIGITS.get(next(iterator), undefined) | 0x80

            yield curr

    except StopIteration:
        pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import re
import os
import sys
from io import open
from setuptools import setup, find_packages


def read_file(fname, encoding='utf-8'):
    with open(fname, encoding=encoding) as r:
        return r.read()


def find_version(*file_paths):
    fpath = os.path.join(os.path.dirname(__file__), *file_paths)
    version_file = read_file(fpath)
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)

    err_msg = 'Unable to find version string in {}'.format(fpath)
    raise RuntimeError(err_msg)


README = read_file('README.rst')
CONTRIB = read_file('CONTRIBUTING.rst')
CHANGES = read_file('CHANGES.rst')
version = find_version('luma', 'lcd', '__init__.py')
project_url = 'https://github.com/rm-hull/luma.lcd'

needs_pytest = {'pytest', 'test', 'ptr'}.intersection(sys.argv)
pytest_runner = ['pytest-runner'] if needs_pytest else []
test_deps = [
    'pytest<=4.5',
    'pytest-cov'
]

setup(
    name="luma.lcd",
    version=version,
    author="Richard Hull",
    author_email="richard.hull@destructuring-bind.org",
    description=("A library to drive PCD8544, HT1621, ST7735, ST7567, UC1701X and ILI9341-based LCDs"),
    long_description="\n\n".join([README, CONTRIB, CHANGES]),
    long_description_content_type="text/x-rst",
    python_requires='>=3.5, <4',
    license="MIT",
    keywords=("raspberry pi rpi lcd display screen "
              "rgb monochrome greyscale color "
              "nokia 5110 pcd8544 st7735 uc1701x ht1621 ili9341 hd44780 "
              "spi i2c parallel bitbang 6800 pcf8574 "),
    url=project_url,
    download_url=project_url + "/tarball/" + version,
    project_urls={
        'Documentation': 'https://luma-lcd.readthedocs.io',
        'Source': project_url,
        'Issue Tracker': project_url + '/issues',
    },
    namespace_packages=["luma"],
    packages=find_packages(),
    zip_safe=False,
    install_requires=["luma.core>=1.16.2"],
    setup_requires=pytest_runner,
    tests_require=test_deps,
    extras_require={
        'docs': [
            'sphinx >= 1.5.3'
        ],
        'qa': [
            'rstcheck',
            'flake8'
        ],
        'test': test_deps
    },
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Education",
        "Intended Audience :: Developers",
        "Topic :: Education",
        "Topic :: System :: Hardware",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8"
    ]
)
